@@ -5,7 +5,7 @@
 #' is returned:
 #' \itemize{
 #' \item{\code{stateCode}}
-#' \item{\code{county}}
+#' \item{\code{countyName}}
 #' \item{\code{censusBlock}}
 #' }
 #' The data from this function should be considered to be the gold standard for state and county.
@@ -18,11 +18,17 @@
 #' \donttest{
 #' library(MazamaLocationUtils)
 #' 
-#' lon <- -77.51
-#' lat <- 38.26
+#' # Fail gracefully if any resources are not available
+#' try({
 #' 
-#' censusList <- location_getCensusBlock(lon, lat)
-#' str(censusList)
+#'   # Wenatchee
+#'   lon <- -120.325278
+#'   lat <- 47.423333
+#' 
+#'   censusList <- location_getCensusBlock(lon, lat)
+#'   str(censusList)
+#'   
+#' }, silent = FALSE)
 #' }
 #' @references \url{https://geo.fcc.gov/api/census/#!/block/get_block_find}
 #' @rdname location_getCensusBlock
@@ -74,7 +80,7 @@ location_getCensusBlock <- function(
     returnObj <- httr::content(r)
     censusList <- list(
       stateCode = returnObj$State$code,
-      county = returnObj$County$name,
+      countyName = returnObj$County$name,
       censusBlock = returnObj$Block$FIPS
     )
     
