@@ -7,21 +7,30 @@ test_that("table_updateColumn() works with no data", {
 })
 
 test_that("table_updateColumn() works with data", {
+  
+  # Update records in a known location table with information obtained elsewhere
+  
   locationTbl <- get(data("wa_monitors_500"))
   wa <- get(data("wa_airfire_meta"))
   
-  # Reord indices into for wa
+  # Record indices into for wa
   wa_indices <- seq(5,65,5)
   wa_sub <- wa[wa_indices,]
   
+  # NOTE:  Some locationIDs may be NA
   locationID <- table_getLocationID(locationTbl, wa_sub$longitude, wa_sub$latitude, distanceThreshold = 1000)
   locationData <- wa_sub$siteName
   
   testTbl <- table_updateColumn(locationTbl, "siteName", locationID, locationData)
+  testTbl_indices <- table_getRecordIndex(testTbl, locationID)
   
-  # Reord indices for testTbl
-  testTbl_indices <- table_getRecordIndex(locationTbl, locationID)
+  locationTbl_siteName <- testTbl$siteName[testTbl_indices]
+  wa_siteName <- wa$siteName[wa_indices]
+  
+  # NOTE:  locationTbl may not have every location in wa
+  mask <- !is.na(locationTbl_siteName)
+
+  expect_equal(locationTbl_siteName[mask], wa_siteName[mask])
   
-  expect_equal(testTbl$siteName[testTbl_indices], wa$siteName[wa_indices])
 })
 
